pub struct ArrayRng<A> { /* private fields */ }Expand description
Random number generator for ndarray
Uses ChaCha8Rng internally because StdRng does not implement Clone in rand 0.10.
Implementations
Sourceimpl<A: Float> ArrayRng<A>
impl<A: Float> ArrayRng<A>
Sourcepub fn from_seed(seed: u64) -> Self
pub fn from_seed(seed: u64) -> Self
Creates a new random number generator with the specified seed.
Sourcepub fn as_rng(&self) -> &ChaCha8Rng
pub fn as_rng(&self) -> &ChaCha8Rng
Returns a reference to the internal RNG
Sourcepub fn as_rng_mut(&mut self) -> &mut ChaCha8Rng
pub fn as_rng_mut(&mut self) -> &mut ChaCha8Rng
Returns a mutable reference to the internal RNG
Sourcepub fn random(&mut self, shape: &[usize]) -> NdArray<A>
pub fn random(&mut self, shape: &[usize]) -> NdArray<A>
Creates a uniform random array in the specified shape. Values are in the range [0, 1)
Sourcepub fn normal(&mut self, shape: &[usize], mean: f64, std: f64) -> NdArray<A>
pub fn normal(&mut self, shape: &[usize], mean: f64, std: f64) -> NdArray<A>
Creates a normal random array in the specified shape. Values are drawn from a normal distribution with the specified mean and standard deviation.
Sourcepub fn uniform(&mut self, shape: &[usize], low: f64, high: f64) -> NdArray<A>
pub fn uniform(&mut self, shape: &[usize], low: f64, high: f64) -> NdArray<A>
Creates a uniform random array in the specified shape. Values are in the range [low, high).
Sourcepub fn glorot_uniform(&mut self, shape: &[usize]) -> NdArray<A>
pub fn glorot_uniform(&mut self, shape: &[usize]) -> NdArray<A>
Creates a random array with Glorot/Xavier uniform initialization. For a tensor with shape (in_features, out_features), samples are drawn from Uniform(-sqrt(6/(in_features+out_features)), sqrt(6/(in_features+out_features))).
Sourcepub fn glorot_normal(&mut self, shape: &[usize]) -> NdArray<A>
pub fn glorot_normal(&mut self, shape: &[usize]) -> NdArray<A>
Creates a random array with Glorot/Xavier normal initialization. For a tensor with shape (in_features, out_features), samples are drawn from Normal(0, sqrt(2/(in_features+out_features))).
Sourcepub fn he_uniform(&mut self, shape: &[usize]) -> NdArray<A>
pub fn he_uniform(&mut self, shape: &[usize]) -> NdArray<A>
Creates a random array with He/Kaiming uniform initialization. For a tensor with shape (in_features, out_features), samples are drawn from Uniform(-sqrt(6/in_features), sqrt(6/in_features)).
Sourcepub fn he_normal(&mut self, shape: &[usize]) -> NdArray<A>
pub fn he_normal(&mut self, shape: &[usize]) -> NdArray<A>
Creates a random array with He/Kaiming normal initialization. For a tensor with shape (in_features, out_features), samples are drawn from Normal(0, sqrt(2/in_features)).
Sourcepub fn standard_normal(&mut self, shape: &[usize]) -> NdArray<A>
pub fn standard_normal(&mut self, shape: &[usize]) -> NdArray<A>
Creates a random array from the standard normal distribution.
Sourcepub fn standard_uniform(&mut self, shape: &[usize]) -> NdArray<A>
pub fn standard_uniform(&mut self, shape: &[usize]) -> NdArray<A>
Creates a random array from the standard uniform distribution.
Sourcepub fn bernoulli(&mut self, shape: &[usize], p: f64) -> NdArray<A>
pub fn bernoulli(&mut self, shape: &[usize], p: f64) -> NdArray<A>
Creates a random array from the bernoulli distribution.
Sourcepub fn exponential(&mut self, shape: &[usize], lambda: f64) -> NdArray<A>
pub fn exponential(&mut self, shape: &[usize], lambda: f64) -> NdArray<A>
Creates a random array from the exponential distribution.